==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/oc/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Enregistrament de las donadas efectuat amb succès',
'L_UPDATE_TITLE'					=> 'Mesa a jorn PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml requerís PHP 5 o superior per foncionar.',

'L_SELECT_LANG'						=> 'Seleccionatz vòstra lenga',
'L_INPUT_CHANGE'					=> 'Cambiar',

'L_UPDATE_UPTODATE'					=> 'Vòstre PluXml es ja a jorn.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Cap de mesa a jorn es pas disponibla.',
'L_UPDATE_BACK'						=> 'Tornar al siti',
'L_UPDATE_WARNING1'					=> 'Anatz metre a jorn vòstra anciana version de PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Volgatz seleccionar dins la lista çai jos vòstra anciana version de PluXml a metre a jorn.',
'L_UPDATE_WARNING2'					=> 'Se vòstra anciana version es pas listada aicí, es qu\'existís pas cap de procedura automatizada de mesa a jorn car vòstra version es tròp vièlha.<br />Nous vous suggérons de télécharger la dernière version de <a href="http://www.pluxml.org">PluXml</a> et de faire une nouvelle installation.',
'L_UPDATE_WARNING3'					=> 'Atencion, abans d\'amodar la mesa a jorn, oblidetz pas de far una salvagarda de vòstras donadas en fasent une còpia del dorsièr "data"',
'L_UPDATE_START'					=> 'Amodar la mesa a jorn',

'L_UPDATE_ENDED'					=> 'Mesa a jorn de la version %s terminada.',
'L_UPDATE_INPROGRESS'				=> 'Aplicacions de las mesas a jorn version',
'L_UPDATE_ERROR'					=> 'Una error s\'es produsida al temps de la mesa a jorn.',
'L_UPDATE_SUCCESSFUL'				=> 'Totas las mesas a jorn son estadas aplicadas amb succès !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Mesa a jorn del fichièr parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Creacion del fichièr tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Error pendent la creacion del fichièr tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Creacion del fichièr tèma',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Error pendent la creacion del fichièr',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Conversion dels articles al novèl format',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Error pendent lo tractament del fichièr',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migracion del fichièr de las paginas estaticas',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Error pendent la migracion del fichièr de las paginas estaticas',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Creacion del fichièr dels utilizators',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Error pendent la creacion del fichièr dels utilizators',
'L_UPDATE_USERS_MIGRATION'			=> 'Migracion del fichièr dels utilizators',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Error pendent la migracion del fichièr dels utilizators',
'L_UPDATE_ERR_NO_USERS'				=> 'Pas cap d\'utilizator present dins lo fichièr',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Creacion del fichièr .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Error pendent la creacion del fichièr .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Mesa a jorn del fichièr .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Error pendent la mesa a jorn del fichièr .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migracion del fichièr de las categorias',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Error pendent la migracion del fichièr de las categorias',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Creacion del fichièr plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Error pendent la creacion del fichièr plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Supression del fichièr core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Error pendent la supression del fichièr core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Supression del dorsièr core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Error pendent la supression del dorsièr core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Mesa a jorn del fichièr',
'L_UPDATE_ERR_FILE'					=> 'Error pendent la mesa a jorn del fichièr',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migracion dels fichièrs de parametratge dels plugins dins lo dorsièr de configuracion',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Mesa a jorn del fichièr plugins.xml',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/oc/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Enregistrament de las donadas efectuat amb succès',
'L_UPDATE_TITLE'					=> 'Mesa a jorn PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml requerís PHP 5 o superior per foncionar.',

'L_SELECT_LANG'						=> 'Seleccionatz vòstra lenga',
'L_INPUT_CHANGE'					=> 'Cambiar',

'L_UPDATE_UPTODATE'					=> 'Vòstre PluXml es ja a jorn.',
'L_UPDATE_NOT_AVAILABLE'			=> 'Cap de mesa a jorn es pas disponibla.',
'L_UPDATE_BACK'						=> 'Tornar al siti',
'L_UPDATE_WARNING1'					=> 'Anatz metre a jorn vòstra anciana version de PluXml',
'L_UPDATE_SELECT_VERSION'			=> 'Volgatz seleccionar dins la lista çai jos vòstra anciana version de PluXml a metre a jorn.',
'L_UPDATE_WARNING2'					=> 'Se vòstra anciana version es pas listada aicí, es qu\'existís pas cap de procedura automatizada de mesa a jorn car vòstra version es tròp vièlha.<br />Nous vous suggérons de télécharger la dernière version de <a href="http://www.pluxml.org">PluXml</a> et de faire une nouvelle installation.',
'L_UPDATE_WARNING3'					=> 'Atencion, abans d\'amodar la mesa a jorn, oblidetz pas de far una salvagarda de vòstras donadas en fasent une còpia del dorsièr "data"',
'L_UPDATE_START'					=> 'Amodar la mesa a jorn',

'L_UPDATE_ENDED'					=> 'Mesa a jorn de la version %s terminada.',
'L_UPDATE_INPROGRESS'				=> 'Aplicacions de las mesas a jorn version',
'L_UPDATE_ERROR'					=> 'Una error s\'es produsida al temps de la mesa a jorn.',
'L_UPDATE_SUCCESSFUL'				=> 'Totas las mesas a jorn son estadas aplicadas amb succès !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Mesa a jorn del fichièr parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'Creacion del fichièr tags.xml',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Error pendent la creacion del fichièr tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Creacion del fichièr tèma',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Error pendent la creacion del fichièr',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Conversion dels articles al novèl format',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Error pendent lo tractament del fichièr',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migracion del fichièr de las paginas estaticas',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Error pendent la migracion del fichièr de las paginas estaticas',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Creacion del fichièr dels utilizators',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Error pendent la creacion del fichièr dels utilizators',
'L_UPDATE_USERS_MIGRATION'			=> 'Migracion del fichièr dels utilizators',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Error pendent la migracion del fichièr dels utilizators',
'L_UPDATE_ERR_NO_USERS'				=> 'Pas cap d\'utilizator present dins lo fichièr',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> 'Creacion del fichièr .htaccess',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Error pendent la creacion del fichièr .htaccess',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Mesa a jorn del fichièr .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Error pendent la mesa a jorn del fichièr .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migracion del fichièr de las categorias',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Error pendent la migracion del fichièr de las categorias',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'Creacion del fichièr plugins.xml',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Error pendent la creacion del fichièr plugins.xml',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Supression del fichièr core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Error pendent la supression del fichièr core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Supression del dorsièr core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Error pendent la supression del dorsièr core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Mesa a jorn del fichièr',
'L_UPDATE_ERR_FILE'					=> 'Error pendent la mesa a jorn del fichièr',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migracion dels fichièrs de parametratge dels plugins dins lo dorsièr de configuracion',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Mesa a jorn del fichièr plugins.xml',
'L_UPDATE_COMMENTS_MIGRATION'		=> 'Migracion dels comentaris',
'L_UPDATE_ERR_COMMENTS_MIGRATION'	=> 'Error pendent la migracion dels comentaris',
);
?>
